@@ -1,4 +1,4 @@
-from typing import Optional, Sequence
+from typing import Optional, Sequence, Union, List
 from datetime import date
 from pydantic import BaseModel
 
@@ -11,7 +11,7 @@ class ESDocument(BaseModel):
     description: str
     type: doc_fields.Type
     uri: str
-    format: Optional[doc_fields.Type]
+    format: Optional[Union[doc_fields.Type, List[doc_fields.Type]]]
     modified: Optional[str] = None
     issued: Optional[str] = None
     periodicity: Optional[str] = ""
@@ -24,7 +24,7 @@ class ESDocument(BaseModel):
     accessRights: Optional[doc_fields.AccessRights] = doc_fields.AccessRights.INTERNAL.value
     pii: Optional[doc_fields.Pii] = doc_fields.Pii.FALSE.value
     keyword: Optional[Sequence] = []
-    theme: Optional[str] = ""
+    theme: Optional[Union[str, List[str]]] = ""
     temporal: Optional[dict] = {"from": f"{date.today().year}", "to": f"{date.today().year}"}
     language: Optional[str] = "NO"
     creator: Optional[dict] = {}
